/*
 * Interface wrapper code.
 *
 * Generated by SIP 4.19.23
 *
 * Copyright (c) 2020 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt5.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtGui.h"

#line 207 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtGui/qcolor.sip"
#include <qcolor.h>
#line 234 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtGui/qcolor.sip"
#include <qcolor.h>
#line 31 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtGui/sipQtGuiQColorConstantsSvg.cpp"

#line 26 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtGui/qcolor.sip"
#include <qcolor.h>
#line 35 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtGui/sipQtGuiQColorConstantsSvg.cpp"


extern "C" {static PyObject *varget_QColorConstants_Svg_aliceblue(void *, PyObject *, PyObject *);}
static PyObject *varget_QColorConstants_Svg_aliceblue(void *, PyObject *, PyObject *)
{
    const  ::QColor*sipVal;

    sipVal = new  ::QColor( ::QColorConstants::Svg::aliceblue);

    return sipConvertFromNewType(const_cast< ::QColor *>(sipVal), sipType_QColor, SIP_NULLPTR);
}


extern "C" {static PyObject *varget_QColorConstants_Svg_antiquewhite(void *, PyObject *, PyObject *);}
static PyObject *varget_QColorConstants_Svg_antiquewhite(void *, PyObject *, PyObject *)
{
    const  ::QColor*sipVal;

    sipVal = new  ::QColor( ::QColorConstants::Svg::antiquewhite);

    return sipConvertFromNewType(const_cast< ::QColor *>(sipVal), sipType_QColor, SIP_NULLPTR);
}


extern "C" {static PyObject *varget_QColorConstants_Svg_aqua(void *, PyObject *, PyObject *);}
static PyObject *varget_QColorConstants_Svg_aqua(void *, PyObject *, PyObject *)
{
    const  ::QColor*sipVal;

    sipVal = new  ::QColor( ::QColorConstants::Svg::aqua);

    return sipConvertFromNewType(const_cast< ::QColor *>(sipVal), sipType_QColor, SIP_NULLPTR);
}


extern "C" {static PyObject *varget_QColorConstants_Svg_aquamarine(void *, PyObject *, PyObject *);}
static PyObject *varget_QColorConstants_Svg_aquamarine(void *, PyObject *, PyObject *)
{
    const  ::QColor*sipVal;

    sipVal = new  ::QColor( ::QColorConstants::Svg::aquamarine);

    return sipConvertFromNewType(const_cast< ::QColor *>(sipVal), sipType_QColor, SIP_NULLPTR);
}


extern "C" {static PyObject *varget_QColorConstants_Svg_azure(void *, PyObject *, PyObject *);}
static PyObject *varget_QColorConstants_Svg_azure(void *, PyObject *, PyObject *)
{
    const  ::QColor*sipVal;

    sipVal = new  ::QColor( ::QColorConstants::Svg::azure);

    return sipConvertFromNewType(const_cast< ::QColor *>(sipVal), sipType_QColor, SIP_NULLPTR);
}


extern "C" {static PyObject *varget_QColorConstants_Svg_beige(void *, PyObject *, PyObject *);}
static PyObject *varget_QColorConstants_Svg_beige(void *, PyObject *, PyObject *)
{
    const  ::QColor*sipVal;

    sipVal = new  ::QColor( ::QColorConstants::Svg::beige);

    return sipConvertFromNewType(const_cast< ::QColor *>(sipVal), sipType_QColor, SIP_NULLPTR);
}


extern "C" {static PyObject *varget_QColorConstants_Svg_bisque(void *, PyObject *, PyObject *);}
static PyObject *varget_QColorConstants_Svg_bisque(void *, PyObject *, PyObject *)
{
    const  ::QColor*sipVal;

    sipVal = new  ::QColor( ::QColorConstants::Svg::bisque);

    return sipConvertFromNewType(const_cast< ::QColor *>(sipVal), sipType_QColor, SIP_NULLPTR);
}


extern "C" {static PyObject *varget_QColorConstants_Svg_black(void *, PyObject *, PyObject *);}
static PyObject *varget_QColorConstants_Svg_black(void *, PyObject *, PyObject *)
{
    const  ::QColor*sipVal;

    sipVal = new  ::QColor( ::QColorConstants::Svg::black);

    return sipConvertFromNewType(const_cast< ::QColor *>(sipVal), sipType_QColor, SIP_NULLPTR);
}


extern "C" {static PyObject *varget_QColorConstants_Svg_blanchedalmond(void *, PyObject *, PyObject *);}
static PyObject *varget_QColorConstants_Svg_blanchedalmond(void *, PyObject *, PyObject *)
{
    const  ::QColor*sipVal;

    sipVal = new  ::QColor( ::QColorConstants::Svg::blanchedalmond);

    return sipConvertFromNewType(const_cast< ::QColor *>(sipVal), sipType_QColor, SIP_NULLPTR);
}


extern "C" {static PyObject *varget_QColorConstants_Svg_blue(void *, PyObject *, PyObject *);}
static PyObject *varget_QColorConstants_Svg_blue(void *, PyObject *, PyObject *)
{
    const  ::QColor*sipVal;

    sipVal = new  ::QColor( ::QColorConstants::Svg::blue);

    return sipConvertFromNewType(const_cast< ::QColor *>(sipVal), sipType_QColor, SIP_NULLPTR);
}


extern "C" {static PyObject *varget_QColorConstants_Svg_blueviolet(void *, PyObject *, PyObject *);}
static PyObject *varget_QColorConstants_Svg_blueviolet(void *, PyObject *, PyObject *)
{
    const  ::QColor*sipVal;

    sipVal = new  ::QColor( ::QColorConstants::Svg::blueviolet);

    return sipConvertFromNewType(const_cast< ::QColor *>(sipVal), sipType_QColor, SIP_NULLPTR);
}


extern "C" {static PyObject *varget_QColorConstants_Svg_brown(void *, PyObject *, PyObject *);}
static PyObject *varget_QColorConstants_Svg_brown(void *, PyObject *, PyObject *)
{
    const  ::QColor*sipVal;

    sipVal = new  ::QColor( ::QColorConstants::Svg::brown);

    return sipConvertFromNewType(const_cast< ::QColor *>(sipVal), sipType_QColor, SIP_NULLPTR);
}


extern "C" {static PyObject *varget_QColorConstants_Svg_burlywood(void *, PyObject *, PyObject *);}
static PyObject *varget_QColorConstants_Svg_burlywood(void *, PyObject *, PyObject *)
{
    const  ::QColor*sipVal;

    sipVal = new  ::QColor( ::QColorConstants::Svg::burlywood);

    return sipConvertFromNewType(const_cast< ::QColor *>(sipVal), sipType_QColor, SIP_NULLPTR);
}


extern "C" {static PyObject *varget_QColorConstants_Svg_cadetblue(void *, PyObject *, PyObject *);}
static PyObject *varget_QColorConstants_Svg_cadetblue(void *, PyObject *, PyObject *)
{
    const  ::QColor*sipVal;

    sipVal = new  ::QColor( ::QColorConstants::Svg::cadetblue);

    return sipConvertFromNewType(const_cast< ::QColor *>(sipVal), sipType_QColor, SIP_NULLPTR);
}


extern "C" {static PyObject *varget_QColorConstants_Svg_chartreuse(void *, PyObject *, PyObject *);}
static PyObject *varget_QColorConstants_Svg_chartreuse(void *, PyObject *, PyObject *)
{
    const  ::QColor*sipVal;

    sipVal = new  ::QColor( ::QColorConstants::Svg::chartreuse);

    return sipConvertFromNewType(const_cast< ::QColor *>(sipVal), sipType_QColor, SIP_NULLPTR);
}


extern "C" {static PyObject *varget_QColorConstants_Svg_chocolate(void *, PyObject *, PyObject *);}
static PyObject *varget_QColorConstants_Svg_chocolate(void *, PyObject *, PyObject *)
{
    const  ::QColor*sipVal;

    sipVal = new  ::QColor( ::QColorConstants::Svg::chocolate);

    return sipConvertFromNewType(const_cast< ::QColor *>(sipVal), sipType_QColor, SIP_NULLPTR);
}


extern "C" {static PyObject *varget_QColorConstants_Svg_coral(void *, PyObject *, PyObject *);}
static PyObject *varget_QColorConstants_Svg_coral(void *, PyObject *, PyObject *)
{
    const  ::QColor*sipVal;

    sipVal = new  ::QColor( ::QColorConstants::Svg::coral);

    return sipConvertFromNewType(const_cast< ::QColor *>(sipVal), sipType_QColor, SIP_NULLPTR);
}


extern "C" {static PyObject *varget_QColorConstants_Svg_cornflowerblue(void *, PyObject *, PyObject *);}
static PyObject *varget_QColorConstants_Svg_cornflowerblue(void *, PyObject *, PyObject *)
{
    const  ::QColor*sipVal;

    sipVal = new  ::QColor( ::QColorConstants::Svg::cornflowerblue);

    return sipConvertFromNewType(const_cast< ::QColor *>(sipVal), sipType_QColor, SIP_NULLPTR);
}


extern "C" {static PyObject *varget_QColorConstants_Svg_cornsilk(void *, PyObject *, PyObject *);}
static PyObject *varget_QColorConstants_Svg_cornsilk(void *, PyObject *, PyObject *)
{
    const  ::QColor*sipVal;

    sipVal = new  ::QColor( ::QColorConstants::Svg::cornsilk);

    return sipConvertFromNewType(const_cast< ::QColor *>(sipVal), sipType_QColor, SIP_NULLPTR);
}


extern "C" {static PyObject *varget_QColorConstants_Svg_crimson(void *, PyObject *, PyObject *);}
static PyObject *varget_QColorConstants_Svg_crimson(void *, PyObject *, PyObject *)
{
    const  ::QColor*sipVal;

    sipVal = new  ::QColor( ::QColorConstants::Svg::crimson);

    return sipConvertFromNewType(const_cast< ::QColor *>(sipVal), sipType_QColor, SIP_NULLPTR);
}


extern "C" {static PyObject *varget_QColorConstants_Svg_cyan(void *, PyObject *, PyObject *);}
static PyObject *varget_QColorConstants_Svg_cyan(void *, PyObject *, PyObject *)
{
    const  ::QColor*sipVal;

    sipVal = new  ::QColor( ::QColorConstants::Svg::cyan);

    return sipConvertFromNewType(const_cast< ::QColor *>(sipVal), sipType_QColor, SIP_NULLPTR);
}


extern "C" {static PyObject *varget_QColorConstants_Svg_darkblue(void *, PyObject *, PyObject *);}
static PyObject *varget_QColorConstants_Svg_darkblue(void *, PyObject *, PyObject *)
{
    const  ::QColor*sipVal;

    sipVal = new  ::QColor( ::QColorConstants::Svg::darkblue);

    return sipConvertFromNewType(const_cast< ::QColor *>(sipVal), sipType_QColor, SIP_NULLPTR);
}


extern "C" {static PyObject *varget_QColorConstants_Svg_darkcyan(void *, PyObject *, PyObject *);}
static PyObject *varget_QColorConstants_Svg_darkcyan(void *, PyObject *, PyObject *)
{
    const  ::QColor*sipVal;

    sipVal = new  ::QColor( ::QColorConstants::Svg::darkcyan);

    return sipConvertFromNewType(const_cast< ::QColor *>(sipVal), sipType_QColor, SIP_NULLPTR);
}


extern "C" {static PyObject *varget_QColorConstants_Svg_darkgoldenrod(void *, PyObject *, PyObject *);}
static PyObject *varget_QColorConstants_Svg_darkgoldenrod(void *, PyObject *, PyObject *)
{
    const  ::QColor*sipVal;

    sipVal = new  ::QColor( ::QColorConstants::Svg::darkgoldenrod);

    return sipConvertFromNewType(const_cast< ::QColor *>(sipVal), sipType_QColor, SIP_NULLPTR);
}


extern "C" {static PyObject *varget_QColorConstants_Svg_darkgray(void *, PyObject *, PyObject *);}
static PyObject *varget_QColorConstants_Svg_darkgray(void *, PyObject *, PyObject *)
{
    const  ::QColor*sipVal;

    sipVal = new  ::QColor( ::QColorConstants::Svg::darkgray);

    return sipConvertFromNewType(const_cast< ::QColor *>(sipVal), sipType_QColor, SIP_NULLPTR);
}


extern "C" {static PyObject *varget_QColorConstants_Svg_darkgreen(void *, PyObject *, PyObject *);}
static PyObject *varget_QColorConstants_Svg_darkgreen(void *, PyObject *, PyObject *)
{
    const  ::QColor*sipVal;

    sipVal = new  ::QColor( ::QColorConstants::Svg::darkgreen);

    return sipConvertFromNewType(const_cast< ::QColor *>(sipVal), sipType_QColor, SIP_NULLPTR);
}


extern "C" {static PyObject *varget_QColorConstants_Svg_darkgrey(void *, PyObject *, PyObject *);}
static PyObject *varget_QColorConstants_Svg_darkgrey(void *, PyObject *, PyObject *)
{
    const  ::QColor*sipVal;

    sipVal = new  ::QColor( ::QColorConstants::Svg::darkgrey);

    return sipConvertFromNewType(const_cast< ::QColor *>(sipVal), sipType_QColor, SIP_NULLPTR);
}


extern "C" {static PyObject *varget_QColorConstants_Svg_darkkhaki(void *, PyObject *, PyObject *);}
static PyObject *varget_QColorConstants_Svg_darkkhaki(void *, PyObject *, PyObject *)
{
    const  ::QColor*sipVal;

    sipVal = new  ::QColor( ::QColorConstants::Svg::darkkhaki);

    return sipConvertFromNewType(const_cast< ::QColor *>(sipVal), sipType_QColor, SIP_NULLPTR);
}


extern "C" {static PyObject *varget_QColorConstants_Svg_darkmagenta(void *, PyObject *, PyObject *);}
static PyObject *varget_QColorConstants_Svg_darkmagenta(void *, PyObject *, PyObject *)
{
    const  ::QColor*sipVal;

    sipVal = new  ::QColor( ::QColorConstants::Svg::darkmagenta);

    return sipConvertFromNewType(const_cast< ::QColor *>(sipVal), sipType_QColor, SIP_NULLPTR);
}


extern "C" {static PyObject *varget_QColorConstants_Svg_darkolivegreen(void *, PyObject *, PyObject *);}
static PyObject *varget_QColorConstants_Svg_darkolivegreen(void *, PyObject *, PyObject *)
{
    const  ::QColor*sipVal;

    sipVal = new  ::QColor( ::QColorConstants::Svg::darkolivegreen);

    return sipConvertFromNewType(const_cast< ::QColor *>(sipVal), sipType_QColor, SIP_NULLPTR);
}


extern "C" {static PyObject *varget_QColorConstants_Svg_darkorange(void *, PyObject *, PyObject *);}
static PyObject *varget_QColorConstants_Svg_darkorange(void *, PyObject *, PyObject *)
{
    const  ::QColor*sipVal;

    sipVal = new  ::QColor( ::QColorConstants::Svg::darkorange);

    return sipConvertFromNewType(const_cast< ::QColor *>(sipVal), sipType_QColor, SIP_NULLPTR);
}


extern "C" {static PyObject *varget_QColorConstants_Svg_darkorchid(void *, PyObject *, PyObject *);}
static PyObject *varget_QColorConstants_Svg_darkorchid(void *, PyObject *, PyObject *)
{
    const  ::QColor*sipVal;

    sipVal = new  ::QColor( ::QColorConstants::Svg::darkorchid);

    return sipConvertFromNewType(const_cast< ::QColor *>(sipVal), sipType_QColor, SIP_NULLPTR);
}


extern "C" {static PyObject *varget_QColorConstants_Svg_darkred(void *, PyObject *, PyObject *);}
static PyObject *varget_QColorConstants_Svg_darkred(void *, PyObject *, PyObject *)
{
    const  ::QColor*sipVal;

    sipVal = new  ::QColor( ::QColorConstants::Svg::darkred);

    return sipConvertFromNewType(const_cast< ::QColor *>(sipVal), sipType_QColor, SIP_NULLPTR);
}


extern "C" {static PyObject *varget_QColorConstants_Svg_darksalmon(void *, PyObject *, PyObject *);}
static PyObject *varget_QColorConstants_Svg_darksalmon(void *, PyObject *, PyObject *)
{
    const  ::QColor*sipVal;

    sipVal = new  ::QColor( ::QColorConstants::Svg::darksalmon);

    return sipConvertFromNewType(const_cast< ::QColor *>(sipVal), sipType_QColor, SIP_NULLPTR);
}


extern "C" {static PyObject *varget_QColorConstants_Svg_darkseagreen(void *, PyObject *, PyObject *);}
static PyObject *varget_QColorConstants_Svg_darkseagreen(void *, PyObject *, PyObject *)
{
    const  ::QColor*sipVal;

    sipVal = new  ::QColor( ::QColorConstants::Svg::darkseagreen);

    return sipConvertFromNewType(const_cast< ::QColor *>(sipVal), sipType_QColor, SIP_NULLPTR);
}


extern "C" {static PyObject *varget_QColorConstants_Svg_darkslateblue(void *, PyObject *, PyObject *);}
static PyObject *varget_QColorConstants_Svg_darkslateblue(void *, PyObject *, PyObject *)
{
    const  ::QColor*sipVal;

    sipVal = new  ::QColor( ::QColorConstants::Svg::darkslateblue);

    return sipConvertFromNewType(const_cast< ::QColor *>(sipVal), sipType_QColor, SIP_NULLPTR);
}


extern "C" {static PyObject *varget_QColorConstants_Svg_darkslategray(void *, PyObject *, PyObject *);}
static PyObject *varget_QColorConstants_Svg_darkslategray(void *, PyObject *, PyObject *)
{
    const  ::QColor*sipVal;

    sipVal = new  ::QColor( ::QColorConstants::Svg::darkslategray);

    return sipConvertFromNewType(const_cast< ::QColor *>(sipVal), sipType_QColor, SIP_NULLPTR);
}


extern "C" {static PyObject *varget_QColorConstants_Svg_darkslategrey(void *, PyObject *, PyObject *);}
static PyObject *varget_QColorConstants_Svg_darkslategrey(void *, PyObject *, PyObject *)
{
    const  ::QColor*sipVal;

    sipVal = new  ::QColor( ::QColorConstants::Svg::darkslategrey);

    return sipConvertFromNewType(const_cast< ::QColor *>(sipVal), sipType_QColor, SIP_NULLPTR);
}


extern "C" {static PyObject *varget_QColorConstants_Svg_darkturquoise(void *, PyObject *, PyObject *);}
static PyObject *varget_QColorConstants_Svg_darkturquoise(void *, PyObject *, PyObject *)
{
    const  ::QColor*sipVal;

    sipVal = new  ::QColor( ::QColorConstants::Svg::darkturquoise);

    return sipConvertFromNewType(const_cast< ::QColor *>(sipVal), sipType_QColor, SIP_NULLPTR);
}


extern "C" {static PyObject *varget_QColorConstants_Svg_darkviolet(void *, PyObject *, PyObject *);}
static PyObject *varget_QColorConstants_Svg_darkviolet(void *, PyObject *, PyObject *)
{
    const  ::QColor*sipVal;

    sipVal = new  ::QColor( ::QColorConstants::Svg::darkviolet);

    return sipConvertFromNewType(const_cast< ::QColor *>(sipVal), sipType_QColor, SIP_NULLPTR);
}


extern "C" {static PyObject *varget_QColorConstants_Svg_deeppink(void *, PyObject *, PyObject *);}
static PyObject *varget_QColorConstants_Svg_deeppink(void *, PyObject *, PyObject *)
{
    const  ::QColor*sipVal;

    sipVal = new  ::QColor( ::QColorConstants::Svg::deeppink);

    return sipConvertFromNewType(const_cast< ::QColor *>(sipVal), sipType_QColor, SIP_NULLPTR);
}


extern "C" {static PyObject *varget_QColorConstants_Svg_deepskyblue(void *, PyObject *, PyObject *);}
static PyObject *varget_QColorConstants_Svg_deepskyblue(void *, PyObject *, PyObject *)
{
    const  ::QColor*sipVal;

    sipVal = new  ::QColor( ::QColorConstants::Svg::deepskyblue);

    return sipConvertFromNewType(const_cast< ::QColor *>(sipVal), sipType_QColor, SIP_NULLPTR);
}


extern "C" {static PyObject *varget_QColorConstants_Svg_dimgray(void *, PyObject *, PyObject *);}
static PyObject *varget_QColorConstants_Svg_dimgray(void *, PyObject *, PyObject *)
{
    const  ::QColor*sipVal;

    sipVal = new  ::QColor( ::QColorConstants::Svg::dimgray);

    return sipConvertFromNewType(const_cast< ::QColor *>(sipVal), sipType_QColor, SIP_NULLPTR);
}


extern "C" {static PyObject *varget_QColorConstants_Svg_dimgrey(void *, PyObject *, PyObject *);}
static PyObject *varget_QColorConstants_Svg_dimgrey(void *, PyObject *, PyObject *)
{
    const  ::QColor*sipVal;

    sipVal = new  ::QColor( ::QColorConstants::Svg::dimgrey);

    return sipConvertFromNewType(const_cast< ::QColor *>(sipVal), sipType_QColor, SIP_NULLPTR);
}


extern "C" {static PyObject *varget_QColorConstants_Svg_dodgerblue(void *, PyObject *, PyObject *);}
static PyObject *varget_QColorConstants_Svg_dodgerblue(void *, PyObject *, PyObject *)
{
    const  ::QColor*sipVal;

    sipVal = new  ::QColor( ::QColorConstants::Svg::dodgerblue);

    return sipConvertFromNewType(const_cast< ::QColor *>(sipVal), sipType_QColor, SIP_NULLPTR);
}


extern "C" {static PyObject *varget_QColorConstants_Svg_firebrick(void *, PyObject *, PyObject *);}
static PyObject *varget_QColorConstants_Svg_firebrick(void *, PyObject *, PyObject *)
{
    const  ::QColor*sipVal;

    sipVal = new  ::QColor( ::QColorConstants::Svg::firebrick);

    return sipConvertFromNewType(const_cast< ::QColor *>(sipVal), sipType_QColor, SIP_NULLPTR);
}


extern "C" {static PyObject *varget_QColorConstants_Svg_floralwhite(void *, PyObject *, PyObject *);}
static PyObject *varget_QColorConstants_Svg_floralwhite(void *, PyObject *, PyObject *)
{
    const  ::QColor*sipVal;

    sipVal = new  ::QColor( ::QColorConstants::Svg::floralwhite);

    return sipConvertFromNewType(const_cast< ::QColor *>(sipVal), sipType_QColor, SIP_NULLPTR);
}


extern "C" {static PyObject *varget_QColorConstants_Svg_forestgreen(void *, PyObject *, PyObject *);}
static PyObject *varget_QColorConstants_Svg_forestgreen(void *, PyObject *, PyObject *)
{
    const  ::QColor*sipVal;

    sipVal = new  ::QColor( ::QColorConstants::Svg::forestgreen);

    return sipConvertFromNewType(const_cast< ::QColor *>(sipVal), sipType_QColor, SIP_NULLPTR);
}


extern "C" {static PyObject *varget_QColorConstants_Svg_fuchsia(void *, PyObject *, PyObject *);}
static PyObject *varget_QColorConstants_Svg_fuchsia(void *, PyObject *, PyObject *)
{
    const  ::QColor*sipVal;

    sipVal = new  ::QColor( ::QColorConstants::Svg::fuchsia);

    return sipConvertFromNewType(const_cast< ::QColor *>(sipVal), sipType_QColor, SIP_NULLPTR);
}


extern "C" {static PyObject *varget_QColorConstants_Svg_gainsboro(void *, PyObject *, PyObject *);}
static PyObject *varget_QColorConstants_Svg_gainsboro(void *, PyObject *, PyObject *)
{
    const  ::QColor*sipVal;

    sipVal = new  ::QColor( ::QColorConstants::Svg::gainsboro);

    return sipConvertFromNewType(const_cast< ::QColor *>(sipVal), sipType_QColor, SIP_NULLPTR);
}


extern "C" {static PyObject *varget_QColorConstants_Svg_ghostwhite(void *, PyObject *, PyObject *);}
static PyObject *varget_QColorConstants_Svg_ghostwhite(void *, PyObject *, PyObject *)
{
    const  ::QColor*sipVal;

    sipVal = new  ::QColor( ::QColorConstants::Svg::ghostwhite);

    return sipConvertFromNewType(const_cast< ::QColor *>(sipVal), sipType_QColor, SIP_NULLPTR);
}


extern "C" {static PyObject *varget_QColorConstants_Svg_gold(void *, PyObject *, PyObject *);}
static PyObject *varget_QColorConstants_Svg_gold(void *, PyObject *, PyObject *)
{
    const  ::QColor*sipVal;

    sipVal = new  ::QColor( ::QColorConstants::Svg::gold);

    return sipConvertFromNewType(const_cast< ::QColor *>(sipVal), sipType_QColor, SIP_NULLPTR);
}


extern "C" {static PyObject *varget_QColorConstants_Svg_goldenrod(void *, PyObject *, PyObject *);}
static PyObject *varget_QColorConstants_Svg_goldenrod(void *, PyObject *, PyObject *)
{
    const  ::QColor*sipVal;

    sipVal = new  ::QColor( ::QColorConstants::Svg::goldenrod);

    return sipConvertFromNewType(const_cast< ::QColor *>(sipVal), sipType_QColor, SIP_NULLPTR);
}


extern "C" {static PyObject *varget_QColorConstants_Svg_gray(void *, PyObject *, PyObject *);}
static PyObject *varget_QColorConstants_Svg_gray(void *, PyObject *, PyObject *)
{
    const  ::QColor*sipVal;

    sipVal = new  ::QColor( ::QColorConstants::Svg::gray);

    return sipConvertFromNewType(const_cast< ::QColor *>(sipVal), sipType_QColor, SIP_NULLPTR);
}


extern "C" {static PyObject *varget_QColorConstants_Svg_green(void *, PyObject *, PyObject *);}
static PyObject *varget_QColorConstants_Svg_green(void *, PyObject *, PyObject *)
{
    const  ::QColor*sipVal;

    sipVal = new  ::QColor( ::QColorConstants::Svg::green);

    return sipConvertFromNewType(const_cast< ::QColor *>(sipVal), sipType_QColor, SIP_NULLPTR);
}


extern "C" {static PyObject *varget_QColorConstants_Svg_greenyellow(void *, PyObject *, PyObject *);}
static PyObject *varget_QColorConstants_Svg_greenyellow(void *, PyObject *, PyObject *)
{
    const  ::QColor*sipVal;

    sipVal = new  ::QColor( ::QColorConstants::Svg::greenyellow);

    return sipConvertFromNewType(const_cast< ::QColor *>(sipVal), sipType_QColor, SIP_NULLPTR);
}


extern "C" {static PyObject *varget_QColorConstants_Svg_grey(void *, PyObject *, PyObject *);}
static PyObject *varget_QColorConstants_Svg_grey(void *, PyObject *, PyObject *)
{
    const  ::QColor*sipVal;

    sipVal = new  ::QColor( ::QColorConstants::Svg::grey);

    return sipConvertFromNewType(const_cast< ::QColor *>(sipVal), sipType_QColor, SIP_NULLPTR);
}


extern "C" {static PyObject *varget_QColorConstants_Svg_honeydew(void *, PyObject *, PyObject *);}
static PyObject *varget_QColorConstants_Svg_honeydew(void *, PyObject *, PyObject *)
{
    const  ::QColor*sipVal;

    sipVal = new  ::QColor( ::QColorConstants::Svg::honeydew);

    return sipConvertFromNewType(const_cast< ::QColor *>(sipVal), sipType_QColor, SIP_NULLPTR);
}


extern "C" {static PyObject *varget_QColorConstants_Svg_hotpink(void *, PyObject *, PyObject *);}
static PyObject *varget_QColorConstants_Svg_hotpink(void *, PyObject *, PyObject *)
{
    const  ::QColor*sipVal;

    sipVal = new  ::QColor( ::QColorConstants::Svg::hotpink);

    return sipConvertFromNewType(const_cast< ::QColor *>(sipVal), sipType_QColor, SIP_NULLPTR);
}


extern "C" {static PyObject *varget_QColorConstants_Svg_indianred(void *, PyObject *, PyObject *);}
static PyObject *varget_QColorConstants_Svg_indianred(void *, PyObject *, PyObject *)
{
    const  ::QColor*sipVal;

    sipVal = new  ::QColor( ::QColorConstants::Svg::indianred);

    return sipConvertFromNewType(const_cast< ::QColor *>(sipVal), sipType_QColor, SIP_NULLPTR);
}


extern "C" {static PyObject *varget_QColorConstants_Svg_indigo(void *, PyObject *, PyObject *);}
static PyObject *varget_QColorConstants_Svg_indigo(void *, PyObject *, PyObject *)
{
    const  ::QColor*sipVal;

    sipVal = new  ::QColor( ::QColorConstants::Svg::indigo);

    return sipConvertFromNewType(const_cast< ::QColor *>(sipVal), sipType_QColor, SIP_NULLPTR);
}


extern "C" {static PyObject *varget_QColorConstants_Svg_ivory(void *, PyObject *, PyObject *);}
static PyObject *varget_QColorConstants_Svg_ivory(void *, PyObject *, PyObject *)
{
    const  ::QColor*sipVal;

    sipVal = new  ::QColor( ::QColorConstants::Svg::ivory);

    return sipConvertFromNewType(const_cast< ::QColor *>(sipVal), sipType_QColor, SIP_NULLPTR);
}


extern "C" {static PyObject *varget_QColorConstants_Svg_khaki(void *, PyObject *, PyObject *);}
static PyObject *varget_QColorConstants_Svg_khaki(void *, PyObject *, PyObject *)
{
    const  ::QColor*sipVal;

    sipVal = new  ::QColor( ::QColorConstants::Svg::khaki);

    return sipConvertFromNewType(const_cast< ::QColor *>(sipVal), sipType_QColor, SIP_NULLPTR);
}


extern "C" {static PyObject *varget_QColorConstants_Svg_lavender(void *, PyObject *, PyObject *);}
static PyObject *varget_QColorConstants_Svg_lavender(void *, PyObject *, PyObject *)
{
    const  ::QColor*sipVal;

    sipVal = new  ::QColor( ::QColorConstants::Svg::lavender);

    return sipConvertFromNewType(const_cast< ::QColor *>(sipVal), sipType_QColor, SIP_NULLPTR);
}


extern "C" {static PyObject *varget_QColorConstants_Svg_lavenderblush(void *, PyObject *, PyObject *);}
static PyObject *varget_QColorConstants_Svg_lavenderblush(void *, PyObject *, PyObject *)
{
    const  ::QColor*sipVal;

    sipVal = new  ::QColor( ::QColorConstants::Svg::lavenderblush);

    return sipConvertFromNewType(const_cast< ::QColor *>(sipVal), sipType_QColor, SIP_NULLPTR);
}


extern "C" {static PyObject *varget_QColorConstants_Svg_lawngreen(void *, PyObject *, PyObject *);}
static PyObject *varget_QColorConstants_Svg_lawngreen(void *, PyObject *, PyObject *)
{
    const  ::QColor*sipVal;

    sipVal = new  ::QColor( ::QColorConstants::Svg::lawngreen);

    return sipConvertFromNewType(const_cast< ::QColor *>(sipVal), sipType_QColor, SIP_NULLPTR);
}


extern "C" {static PyObject *varget_QColorConstants_Svg_lemonchiffon(void *, PyObject *, PyObject *);}
static PyObject *varget_QColorConstants_Svg_lemonchiffon(void *, PyObject *, PyObject *)
{
    const  ::QColor*sipVal;

    sipVal = new  ::QColor( ::QColorConstants::Svg::lemonchiffon);

    return sipConvertFromNewType(const_cast< ::QColor *>(sipVal), sipType_QColor, SIP_NULLPTR);
}


extern "C" {static PyObject *varget_QColorConstants_Svg_lightblue(void *, PyObject *, PyObject *);}
static PyObject *varget_QColorConstants_Svg_lightblue(void *, PyObject *, PyObject *)
{
    const  ::QColor*sipVal;

    sipVal = new  ::QColor( ::QColorConstants::Svg::lightblue);

    return sipConvertFromNewType(const_cast< ::QColor *>(sipVal), sipType_QColor, SIP_NULLPTR);
}


extern "C" {static PyObject *varget_QColorConstants_Svg_lightcoral(void *, PyObject *, PyObject *);}
static PyObject *varget_QColorConstants_Svg_lightcoral(void *, PyObject *, PyObject *)
{
    const  ::QColor*sipVal;

    sipVal = new  ::QColor( ::QColorConstants::Svg::lightcoral);

    return sipConvertFromNewType(const_cast< ::QColor *>(sipVal), sipType_QColor, SIP_NULLPTR);
}


extern "C" {static PyObject *varget_QColorConstants_Svg_lightcyan(void *, PyObject *, PyObject *);}
static PyObject *varget_QColorConstants_Svg_lightcyan(void *, PyObject *, PyObject *)
{
    const  ::QColor*sipVal;

    sipVal = new  ::QColor( ::QColorConstants::Svg::lightcyan);

    return sipConvertFromNewType(const_cast< ::QColor *>(sipVal), sipType_QColor, SIP_NULLPTR);
}


extern "C" {static PyObject *varget_QColorConstants_Svg_lightgoldenrodyellow(void *, PyObject *, PyObject *);}
static PyObject *varget_QColorConstants_Svg_lightgoldenrodyellow(void *, PyObject *, PyObject *)
{
    const  ::QColor*sipVal;

    sipVal = new  ::QColor( ::QColorConstants::Svg::lightgoldenrodyellow);

    return sipConvertFromNewType(const_cast< ::QColor *>(sipVal), sipType_QColor, SIP_NULLPTR);
}


extern "C" {static PyObject *varget_QColorConstants_Svg_lightgray(void *, PyObject *, PyObject *);}
static PyObject *varget_QColorConstants_Svg_lightgray(void *, PyObject *, PyObject *)
{
    const  ::QColor*sipVal;

    sipVal = new  ::QColor( ::QColorConstants::Svg::lightgray);

    return sipConvertFromNewType(const_cast< ::QColor *>(sipVal), sipType_QColor, SIP_NULLPTR);
}


extern "C" {static PyObject *varget_QColorConstants_Svg_lightgreen(void *, PyObject *, PyObject *);}
static PyObject *varget_QColorConstants_Svg_lightgreen(void *, PyObject *, PyObject *)
{
    const  ::QColor*sipVal;

    sipVal = new  ::QColor( ::QColorConstants::Svg::lightgreen);

    return sipConvertFromNewType(const_cast< ::QColor *>(sipVal), sipType_QColor, SIP_NULLPTR);
}


extern "C" {static PyObject *varget_QColorConstants_Svg_lightgrey(void *, PyObject *, PyObject *);}
static PyObject *varget_QColorConstants_Svg_lightgrey(void *, PyObject *, PyObject *)
{
    const  ::QColor*sipVal;

    sipVal = new  ::QColor( ::QColorConstants::Svg::lightgrey);

    return sipConvertFromNewType(const_cast< ::QColor *>(sipVal), sipType_QColor, SIP_NULLPTR);
}


extern "C" {static PyObject *varget_QColorConstants_Svg_lightpink(void *, PyObject *, PyObject *);}
static PyObject *varget_QColorConstants_Svg_lightpink(void *, PyObject *, PyObject *)
{
    const  ::QColor*sipVal;

    sipVal = new  ::QColor( ::QColorConstants::Svg::lightpink);

    return sipConvertFromNewType(const_cast< ::QColor *>(sipVal), sipType_QColor, SIP_NULLPTR);
}


extern "C" {static PyObject *varget_QColorConstants_Svg_lightsalmon(void *, PyObject *, PyObject *);}
static PyObject *varget_QColorConstants_Svg_lightsalmon(void *, PyObject *, PyObject *)
{
    const  ::QColor*sipVal;

    sipVal = new  ::QColor( ::QColorConstants::Svg::lightsalmon);

    return sipConvertFromNewType(const_cast< ::QColor *>(sipVal), sipType_QColor, SIP_NULLPTR);
}


extern "C" {static PyObject *varget_QColorConstants_Svg_lightseagreen(void *, PyObject *, PyObject *);}
static PyObject *varget_QColorConstants_Svg_lightseagreen(void *, PyObject *, PyObject *)
{
    const  ::QColor*sipVal;

    sipVal = new  ::QColor( ::QColorConstants::Svg::lightseagreen);

    return sipConvertFromNewType(const_cast< ::QColor *>(sipVal), sipType_QColor, SIP_NULLPTR);
}


extern "C" {static PyObject *varget_QColorConstants_Svg_lightskyblue(void *, PyObject *, PyObject *);}
static PyObject *varget_QColorConstants_Svg_lightskyblue(void *, PyObject *, PyObject *)
{
    const  ::QColor*sipVal;

    sipVal = new  ::QColor( ::QColorConstants::Svg::lightskyblue);

    return sipConvertFromNewType(const_cast< ::QColor *>(sipVal), sipType_QColor, SIP_NULLPTR);
}


extern "C" {static PyObject *varget_QColorConstants_Svg_lightslategray(void *, PyObject *, PyObject *);}
static PyObject *varget_QColorConstants_Svg_lightslategray(void *, PyObject *, PyObject *)
{
    const  ::QColor*sipVal;

    sipVal = new  ::QColor( ::QColorConstants::Svg::lightslategray);

    return sipConvertFromNewType(const_cast< ::QColor *>(sipVal), sipType_QColor, SIP_NULLPTR);
}


extern "C" {static PyObject *varget_QColorConstants_Svg_lightslategrey(void *, PyObject *, PyObject *);}
static PyObject *varget_QColorConstants_Svg_lightslategrey(void *, PyObject *, PyObject *)
{
    const  ::QColor*sipVal;

    sipVal = new  ::QColor( ::QColorConstants::Svg::lightslategrey);

    return sipConvertFromNewType(const_cast< ::QColor *>(sipVal), sipType_QColor, SIP_NULLPTR);
}


extern "C" {static PyObject *varget_QColorConstants_Svg_lightsteelblue(void *, PyObject *, PyObject *);}
static PyObject *varget_QColorConstants_Svg_lightsteelblue(void *, PyObject *, PyObject *)
{
    const  ::QColor*sipVal;

    sipVal = new  ::QColor( ::QColorConstants::Svg::lightsteelblue);

    return sipConvertFromNewType(const_cast< ::QColor *>(sipVal), sipType_QColor, SIP_NULLPTR);
}


extern "C" {static PyObject *varget_QColorConstants_Svg_lightyellow(void *, PyObject *, PyObject *);}
static PyObject *varget_QColorConstants_Svg_lightyellow(void *, PyObject *, PyObject *)
{
    const  ::QColor*sipVal;

    sipVal = new  ::QColor( ::QColorConstants::Svg::lightyellow);

    return sipConvertFromNewType(const_cast< ::QColor *>(sipVal), sipType_QColor, SIP_NULLPTR);
}


extern "C" {static PyObject *varget_QColorConstants_Svg_lime(void *, PyObject *, PyObject *);}
static PyObject *varget_QColorConstants_Svg_lime(void *, PyObject *, PyObject *)
{
    const  ::QColor*sipVal;

    sipVal = new  ::QColor( ::QColorConstants::Svg::lime);

    return sipConvertFromNewType(const_cast< ::QColor *>(sipVal), sipType_QColor, SIP_NULLPTR);
}


extern "C" {static PyObject *varget_QColorConstants_Svg_limegreen(void *, PyObject *, PyObject *);}
static PyObject *varget_QColorConstants_Svg_limegreen(void *, PyObject *, PyObject *)
{
    const  ::QColor*sipVal;

    sipVal = new  ::QColor( ::QColorConstants::Svg::limegreen);

    return sipConvertFromNewType(const_cast< ::QColor *>(sipVal), sipType_QColor, SIP_NULLPTR);
}


extern "C" {static PyObject *varget_QColorConstants_Svg_linen(void *, PyObject *, PyObject *);}
static PyObject *varget_QColorConstants_Svg_linen(void *, PyObject *, PyObject *)
{
    const  ::QColor*sipVal;

    sipVal = new  ::QColor( ::QColorConstants::Svg::linen);

    return sipConvertFromNewType(const_cast< ::QColor *>(sipVal), sipType_QColor, SIP_NULLPTR);
}


extern "C" {static PyObject *varget_QColorConstants_Svg_magenta(void *, PyObject *, PyObject *);}
static PyObject *varget_QColorConstants_Svg_magenta(void *, PyObject *, PyObject *)
{
    const  ::QColor*sipVal;

    sipVal = new  ::QColor( ::QColorConstants::Svg::magenta);

    return sipConvertFromNewType(const_cast< ::QColor *>(sipVal), sipType_QColor, SIP_NULLPTR);
}


extern "C" {static PyObject *varget_QColorConstants_Svg_maroon(void *, PyObject *, PyObject *);}
static PyObject *varget_QColorConstants_Svg_maroon(void *, PyObject *, PyObject *)
{
    const  ::QColor*sipVal;

    sipVal = new  ::QColor( ::QColorConstants::Svg::maroon);

    return sipConvertFromNewType(const_cast< ::QColor *>(sipVal), sipType_QColor, SIP_NULLPTR);
}


extern "C" {static PyObject *varget_QColorConstants_Svg_mediumaquamarine(void *, PyObject *, PyObject *);}
static PyObject *varget_QColorConstants_Svg_mediumaquamarine(void *, PyObject *, PyObject *)
{
    const  ::QColor*sipVal;

    sipVal = new  ::QColor( ::QColorConstants::Svg::mediumaquamarine);

    return sipConvertFromNewType(const_cast< ::QColor *>(sipVal), sipType_QColor, SIP_NULLPTR);
}


extern "C" {static PyObject *varget_QColorConstants_Svg_mediumblue(void *, PyObject *, PyObject *);}
static PyObject *varget_QColorConstants_Svg_mediumblue(void *, PyObject *, PyObject *)
{
    const  ::QColor*sipVal;

    sipVal = new  ::QColor( ::QColorConstants::Svg::mediumblue);

    return sipConvertFromNewType(const_cast< ::QColor *>(sipVal), sipType_QColor, SIP_NULLPTR);
}


extern "C" {static PyObject *varget_QColorConstants_Svg_mediumorchid(void *, PyObject *, PyObject *);}
static PyObject *varget_QColorConstants_Svg_mediumorchid(void *, PyObject *, PyObject *)
{
    const  ::QColor*sipVal;

    sipVal = new  ::QColor( ::QColorConstants::Svg::mediumorchid);

    return sipConvertFromNewType(const_cast< ::QColor *>(sipVal), sipType_QColor, SIP_NULLPTR);
}


extern "C" {static PyObject *varget_QColorConstants_Svg_mediumpurple(void *, PyObject *, PyObject *);}
static PyObject *varget_QColorConstants_Svg_mediumpurple(void *, PyObject *, PyObject *)
{
    const  ::QColor*sipVal;

    sipVal = new  ::QColor( ::QColorConstants::Svg::mediumpurple);

    return sipConvertFromNewType(const_cast< ::QColor *>(sipVal), sipType_QColor, SIP_NULLPTR);
}


extern "C" {static PyObject *varget_QColorConstants_Svg_mediumseagreen(void *, PyObject *, PyObject *);}
static PyObject *varget_QColorConstants_Svg_mediumseagreen(void *, PyObject *, PyObject *)
{
    const  ::QColor*sipVal;

    sipVal = new  ::QColor( ::QColorConstants::Svg::mediumseagreen);

    return sipConvertFromNewType(const_cast< ::QColor *>(sipVal), sipType_QColor, SIP_NULLPTR);
}


extern "C" {static PyObject *varget_QColorConstants_Svg_mediumslateblue(void *, PyObject *, PyObject *);}
static PyObject *varget_QColorConstants_Svg_mediumslateblue(void *, PyObject *, PyObject *)
{
    const  ::QColor*sipVal;

    sipVal = new  ::QColor( ::QColorConstants::Svg::mediumslateblue);

    return sipConvertFromNewType(const_cast< ::QColor *>(sipVal), sipType_QColor, SIP_NULLPTR);
}


extern "C" {static PyObject *varget_QColorConstants_Svg_mediumspringgreen(void *, PyObject *, PyObject *);}
static PyObject *varget_QColorConstants_Svg_mediumspringgreen(void *, PyObject *, PyObject *)
{
    const  ::QColor*sipVal;

    sipVal = new  ::QColor( ::QColorConstants::Svg::mediumspringgreen);

    return sipConvertFromNewType(const_cast< ::QColor *>(sipVal), sipType_QColor, SIP_NULLPTR);
}


extern "C" {static PyObject *varget_QColorConstants_Svg_mediumturquoise(void *, PyObject *, PyObject *);}
static PyObject *varget_QColorConstants_Svg_mediumturquoise(void *, PyObject *, PyObject *)
{
    const  ::QColor*sipVal;

    sipVal = new  ::QColor( ::QColorConstants::Svg::mediumturquoise);

    return sipConvertFromNewType(const_cast< ::QColor *>(sipVal), sipType_QColor, SIP_NULLPTR);
}


extern "C" {static PyObject *varget_QColorConstants_Svg_mediumvioletred(void *, PyObject *, PyObject *);}
static PyObject *varget_QColorConstants_Svg_mediumvioletred(void *, PyObject *, PyObject *)
{
    const  ::QColor*sipVal;

    sipVal = new  ::QColor( ::QColorConstants::Svg::mediumvioletred);

    return sipConvertFromNewType(const_cast< ::QColor *>(sipVal), sipType_QColor, SIP_NULLPTR);
}


extern "C" {static PyObject *varget_QColorConstants_Svg_midnightblue(void *, PyObject *, PyObject *);}
static PyObject *varget_QColorConstants_Svg_midnightblue(void *, PyObject *, PyObject *)
{
    const  ::QColor*sipVal;

    sipVal = new  ::QColor( ::QColorConstants::Svg::midnightblue);

    return sipConvertFromNewType(const_cast< ::QColor *>(sipVal), sipType_QColor, SIP_NULLPTR);
}


extern "C" {static PyObject *varget_QColorConstants_Svg_mintcream(void *, PyObject *, PyObject *);}
static PyObject *varget_QColorConstants_Svg_mintcream(void *, PyObject *, PyObject *)
{
    const  ::QColor*sipVal;

    sipVal = new  ::QColor( ::QColorConstants::Svg::mintcream);

    return sipConvertFromNewType(const_cast< ::QColor *>(sipVal), sipType_QColor, SIP_NULLPTR);
}


extern "C" {static PyObject *varget_QColorConstants_Svg_mistyrose(void *, PyObject *, PyObject *);}
static PyObject *varget_QColorConstants_Svg_mistyrose(void *, PyObject *, PyObject *)
{
    const  ::QColor*sipVal;

    sipVal = new  ::QColor( ::QColorConstants::Svg::mistyrose);

    return sipConvertFromNewType(const_cast< ::QColor *>(sipVal), sipType_QColor, SIP_NULLPTR);
}


extern "C" {static PyObject *varget_QColorConstants_Svg_moccasin(void *, PyObject *, PyObject *);}
static PyObject *varget_QColorConstants_Svg_moccasin(void *, PyObject *, PyObject *)
{
    const  ::QColor*sipVal;

    sipVal = new  ::QColor( ::QColorConstants::Svg::moccasin);

    return sipConvertFromNewType(const_cast< ::QColor *>(sipVal), sipType_QColor, SIP_NULLPTR);
}


extern "C" {static PyObject *varget_QColorConstants_Svg_navajowhite(void *, PyObject *, PyObject *);}
static PyObject *varget_QColorConstants_Svg_navajowhite(void *, PyObject *, PyObject *)
{
    const  ::QColor*sipVal;

    sipVal = new  ::QColor( ::QColorConstants::Svg::navajowhite);

    return sipConvertFromNewType(const_cast< ::QColor *>(sipVal), sipType_QColor, SIP_NULLPTR);
}


extern "C" {static PyObject *varget_QColorConstants_Svg_navy(void *, PyObject *, PyObject *);}
static PyObject *varget_QColorConstants_Svg_navy(void *, PyObject *, PyObject *)
{
    const  ::QColor*sipVal;

    sipVal = new  ::QColor( ::QColorConstants::Svg::navy);

    return sipConvertFromNewType(const_cast< ::QColor *>(sipVal), sipType_QColor, SIP_NULLPTR);
}


extern "C" {static PyObject *varget_QColorConstants_Svg_oldlace(void *, PyObject *, PyObject *);}
static PyObject *varget_QColorConstants_Svg_oldlace(void *, PyObject *, PyObject *)
{
    const  ::QColor*sipVal;

    sipVal = new  ::QColor( ::QColorConstants::Svg::oldlace);

    return sipConvertFromNewType(const_cast< ::QColor *>(sipVal), sipType_QColor, SIP_NULLPTR);
}


extern "C" {static PyObject *varget_QColorConstants_Svg_olive(void *, PyObject *, PyObject *);}
static PyObject *varget_QColorConstants_Svg_olive(void *, PyObject *, PyObject *)
{
    const  ::QColor*sipVal;

    sipVal = new  ::QColor( ::QColorConstants::Svg::olive);

    return sipConvertFromNewType(const_cast< ::QColor *>(sipVal), sipType_QColor, SIP_NULLPTR);
}


extern "C" {static PyObject *varget_QColorConstants_Svg_olivedrab(void *, PyObject *, PyObject *);}
static PyObject *varget_QColorConstants_Svg_olivedrab(void *, PyObject *, PyObject *)
{
    const  ::QColor*sipVal;

    sipVal = new  ::QColor( ::QColorConstants::Svg::olivedrab);

    return sipConvertFromNewType(const_cast< ::QColor *>(sipVal), sipType_QColor, SIP_NULLPTR);
}


extern "C" {static PyObject *varget_QColorConstants_Svg_orange(void *, PyObject *, PyObject *);}
static PyObject *varget_QColorConstants_Svg_orange(void *, PyObject *, PyObject *)
{
    const  ::QColor*sipVal;

    sipVal = new  ::QColor( ::QColorConstants::Svg::orange);

    return sipConvertFromNewType(const_cast< ::QColor *>(sipVal), sipType_QColor, SIP_NULLPTR);
}


extern "C" {static PyObject *varget_QColorConstants_Svg_orangered(void *, PyObject *, PyObject *);}
static PyObject *varget_QColorConstants_Svg_orangered(void *, PyObject *, PyObject *)
{
    const  ::QColor*sipVal;

    sipVal = new  ::QColor( ::QColorConstants::Svg::orangered);

    return sipConvertFromNewType(const_cast< ::QColor *>(sipVal), sipType_QColor, SIP_NULLPTR);
}


extern "C" {static PyObject *varget_QColorConstants_Svg_orchid(void *, PyObject *, PyObject *);}
static PyObject *varget_QColorConstants_Svg_orchid(void *, PyObject *, PyObject *)
{
    const  ::QColor*sipVal;

    sipVal = new  ::QColor( ::QColorConstants::Svg::orchid);

    return sipConvertFromNewType(const_cast< ::QColor *>(sipVal), sipType_QColor, SIP_NULLPTR);
}


extern "C" {static PyObject *varget_QColorConstants_Svg_palegoldenrod(void *, PyObject *, PyObject *);}
static PyObject *varget_QColorConstants_Svg_palegoldenrod(void *, PyObject *, PyObject *)
{
    const  ::QColor*sipVal;

    sipVal = new  ::QColor( ::QColorConstants::Svg::palegoldenrod);

    return sipConvertFromNewType(const_cast< ::QColor *>(sipVal), sipType_QColor, SIP_NULLPTR);
}


extern "C" {static PyObject *varget_QColorConstants_Svg_palegreen(void *, PyObject *, PyObject *);}
static PyObject *varget_QColorConstants_Svg_palegreen(void *, PyObject *, PyObject *)
{
    const  ::QColor*sipVal;

    sipVal = new  ::QColor( ::QColorConstants::Svg::palegreen);

    return sipConvertFromNewType(const_cast< ::QColor *>(sipVal), sipType_QColor, SIP_NULLPTR);
}


extern "C" {static PyObject *varget_QColorConstants_Svg_paleturquoise(void *, PyObject *, PyObject *);}
static PyObject *varget_QColorConstants_Svg_paleturquoise(void *, PyObject *, PyObject *)
{
    const  ::QColor*sipVal;

    sipVal = new  ::QColor( ::QColorConstants::Svg::paleturquoise);

    return sipConvertFromNewType(const_cast< ::QColor *>(sipVal), sipType_QColor, SIP_NULLPTR);
}


extern "C" {static PyObject *varget_QColorConstants_Svg_palevioletred(void *, PyObject *, PyObject *);}
static PyObject *varget_QColorConstants_Svg_palevioletred(void *, PyObject *, PyObject *)
{
    const  ::QColor*sipVal;

    sipVal = new  ::QColor( ::QColorConstants::Svg::palevioletred);

    return sipConvertFromNewType(const_cast< ::QColor *>(sipVal), sipType_QColor, SIP_NULLPTR);
}


extern "C" {static PyObject *varget_QColorConstants_Svg_papayawhip(void *, PyObject *, PyObject *);}
static PyObject *varget_QColorConstants_Svg_papayawhip(void *, PyObject *, PyObject *)
{
    const  ::QColor*sipVal;

    sipVal = new  ::QColor( ::QColorConstants::Svg::papayawhip);

    return sipConvertFromNewType(const_cast< ::QColor *>(sipVal), sipType_QColor, SIP_NULLPTR);
}


extern "C" {static PyObject *varget_QColorConstants_Svg_peachpuff(void *, PyObject *, PyObject *);}
static PyObject *varget_QColorConstants_Svg_peachpuff(void *, PyObject *, PyObject *)
{
    const  ::QColor*sipVal;

    sipVal = new  ::QColor( ::QColorConstants::Svg::peachpuff);

    return sipConvertFromNewType(const_cast< ::QColor *>(sipVal), sipType_QColor, SIP_NULLPTR);
}


extern "C" {static PyObject *varget_QColorConstants_Svg_peru(void *, PyObject *, PyObject *);}
static PyObject *varget_QColorConstants_Svg_peru(void *, PyObject *, PyObject *)
{
    const  ::QColor*sipVal;

    sipVal = new  ::QColor( ::QColorConstants::Svg::peru);

    return sipConvertFromNewType(const_cast< ::QColor *>(sipVal), sipType_QColor, SIP_NULLPTR);
}


extern "C" {static PyObject *varget_QColorConstants_Svg_pink(void *, PyObject *, PyObject *);}
static PyObject *varget_QColorConstants_Svg_pink(void *, PyObject *, PyObject *)
{
    const  ::QColor*sipVal;

    sipVal = new  ::QColor( ::QColorConstants::Svg::pink);

    return sipConvertFromNewType(const_cast< ::QColor *>(sipVal), sipType_QColor, SIP_NULLPTR);
}


extern "C" {static PyObject *varget_QColorConstants_Svg_plum(void *, PyObject *, PyObject *);}
static PyObject *varget_QColorConstants_Svg_plum(void *, PyObject *, PyObject *)
{
    const  ::QColor*sipVal;

    sipVal = new  ::QColor( ::QColorConstants::Svg::plum);

    return sipConvertFromNewType(const_cast< ::QColor *>(sipVal), sipType_QColor, SIP_NULLPTR);
}


extern "C" {static PyObject *varget_QColorConstants_Svg_powderblue(void *, PyObject *, PyObject *);}
static PyObject *varget_QColorConstants_Svg_powderblue(void *, PyObject *, PyObject *)
{
    const  ::QColor*sipVal;

    sipVal = new  ::QColor( ::QColorConstants::Svg::powderblue);

    return sipConvertFromNewType(const_cast< ::QColor *>(sipVal), sipType_QColor, SIP_NULLPTR);
}


extern "C" {static PyObject *varget_QColorConstants_Svg_purple(void *, PyObject *, PyObject *);}
static PyObject *varget_QColorConstants_Svg_purple(void *, PyObject *, PyObject *)
{
    const  ::QColor*sipVal;

    sipVal = new  ::QColor( ::QColorConstants::Svg::purple);

    return sipConvertFromNewType(const_cast< ::QColor *>(sipVal), sipType_QColor, SIP_NULLPTR);
}


extern "C" {static PyObject *varget_QColorConstants_Svg_red(void *, PyObject *, PyObject *);}
static PyObject *varget_QColorConstants_Svg_red(void *, PyObject *, PyObject *)
{
    const  ::QColor*sipVal;

    sipVal = new  ::QColor( ::QColorConstants::Svg::red);

    return sipConvertFromNewType(const_cast< ::QColor *>(sipVal), sipType_QColor, SIP_NULLPTR);
}


extern "C" {static PyObject *varget_QColorConstants_Svg_rosybrown(void *, PyObject *, PyObject *);}
static PyObject *varget_QColorConstants_Svg_rosybrown(void *, PyObject *, PyObject *)
{
    const  ::QColor*sipVal;

    sipVal = new  ::QColor( ::QColorConstants::Svg::rosybrown);

    return sipConvertFromNewType(const_cast< ::QColor *>(sipVal), sipType_QColor, SIP_NULLPTR);
}


extern "C" {static PyObject *varget_QColorConstants_Svg_royalblue(void *, PyObject *, PyObject *);}
static PyObject *varget_QColorConstants_Svg_royalblue(void *, PyObject *, PyObject *)
{
    const  ::QColor*sipVal;

    sipVal = new  ::QColor( ::QColorConstants::Svg::royalblue);

    return sipConvertFromNewType(const_cast< ::QColor *>(sipVal), sipType_QColor, SIP_NULLPTR);
}


extern "C" {static PyObject *varget_QColorConstants_Svg_saddlebrown(void *, PyObject *, PyObject *);}
static PyObject *varget_QColorConstants_Svg_saddlebrown(void *, PyObject *, PyObject *)
{
    const  ::QColor*sipVal;

    sipVal = new  ::QColor( ::QColorConstants::Svg::saddlebrown);

    return sipConvertFromNewType(const_cast< ::QColor *>(sipVal), sipType_QColor, SIP_NULLPTR);
}


extern "C" {static PyObject *varget_QColorConstants_Svg_salmon(void *, PyObject *, PyObject *);}
static PyObject *varget_QColorConstants_Svg_salmon(void *, PyObject *, PyObject *)
{
    const  ::QColor*sipVal;

    sipVal = new  ::QColor( ::QColorConstants::Svg::salmon);

    return sipConvertFromNewType(const_cast< ::QColor *>(sipVal), sipType_QColor, SIP_NULLPTR);
}


extern "C" {static PyObject *varget_QColorConstants_Svg_sandybrown(void *, PyObject *, PyObject *);}
static PyObject *varget_QColorConstants_Svg_sandybrown(void *, PyObject *, PyObject *)
{
    const  ::QColor*sipVal;

    sipVal = new  ::QColor( ::QColorConstants::Svg::sandybrown);

    return sipConvertFromNewType(const_cast< ::QColor *>(sipVal), sipType_QColor, SIP_NULLPTR);
}


extern "C" {static PyObject *varget_QColorConstants_Svg_seagreen(void *, PyObject *, PyObject *);}
static PyObject *varget_QColorConstants_Svg_seagreen(void *, PyObject *, PyObject *)
{
    const  ::QColor*sipVal;

    sipVal = new  ::QColor( ::QColorConstants::Svg::seagreen);

    return sipConvertFromNewType(const_cast< ::QColor *>(sipVal), sipType_QColor, SIP_NULLPTR);
}


extern "C" {static PyObject *varget_QColorConstants_Svg_seashell(void *, PyObject *, PyObject *);}
static PyObject *varget_QColorConstants_Svg_seashell(void *, PyObject *, PyObject *)
{
    const  ::QColor*sipVal;

    sipVal = new  ::QColor( ::QColorConstants::Svg::seashell);

    return sipConvertFromNewType(const_cast< ::QColor *>(sipVal), sipType_QColor, SIP_NULLPTR);
}


extern "C" {static PyObject *varget_QColorConstants_Svg_sienna(void *, PyObject *, PyObject *);}
static PyObject *varget_QColorConstants_Svg_sienna(void *, PyObject *, PyObject *)
{
    const  ::QColor*sipVal;

    sipVal = new  ::QColor( ::QColorConstants::Svg::sienna);

    return sipConvertFromNewType(const_cast< ::QColor *>(sipVal), sipType_QColor, SIP_NULLPTR);
}


extern "C" {static PyObject *varget_QColorConstants_Svg_silver(void *, PyObject *, PyObject *);}
static PyObject *varget_QColorConstants_Svg_silver(void *, PyObject *, PyObject *)
{
    const  ::QColor*sipVal;

    sipVal = new  ::QColor( ::QColorConstants::Svg::silver);

    return sipConvertFromNewType(const_cast< ::QColor *>(sipVal), sipType_QColor, SIP_NULLPTR);
}


extern "C" {static PyObject *varget_QColorConstants_Svg_skyblue(void *, PyObject *, PyObject *);}
static PyObject *varget_QColorConstants_Svg_skyblue(void *, PyObject *, PyObject *)
{
    const  ::QColor*sipVal;

    sipVal = new  ::QColor( ::QColorConstants::Svg::skyblue);

    return sipConvertFromNewType(const_cast< ::QColor *>(sipVal), sipType_QColor, SIP_NULLPTR);
}


extern "C" {static PyObject *varget_QColorConstants_Svg_slateblue(void *, PyObject *, PyObject *);}
static PyObject *varget_QColorConstants_Svg_slateblue(void *, PyObject *, PyObject *)
{
    const  ::QColor*sipVal;

    sipVal = new  ::QColor( ::QColorConstants::Svg::slateblue);

    return sipConvertFromNewType(const_cast< ::QColor *>(sipVal), sipType_QColor, SIP_NULLPTR);
}


extern "C" {static PyObject *varget_QColorConstants_Svg_slategray(void *, PyObject *, PyObject *);}
static PyObject *varget_QColorConstants_Svg_slategray(void *, PyObject *, PyObject *)
{
    const  ::QColor*sipVal;

    sipVal = new  ::QColor( ::QColorConstants::Svg::slategray);

    return sipConvertFromNewType(const_cast< ::QColor *>(sipVal), sipType_QColor, SIP_NULLPTR);
}


extern "C" {static PyObject *varget_QColorConstants_Svg_slategrey(void *, PyObject *, PyObject *);}
static PyObject *varget_QColorConstants_Svg_slategrey(void *, PyObject *, PyObject *)
{
    const  ::QColor*sipVal;

    sipVal = new  ::QColor( ::QColorConstants::Svg::slategrey);

    return sipConvertFromNewType(const_cast< ::QColor *>(sipVal), sipType_QColor, SIP_NULLPTR);
}


extern "C" {static PyObject *varget_QColorConstants_Svg_snow(void *, PyObject *, PyObject *);}
static PyObject *varget_QColorConstants_Svg_snow(void *, PyObject *, PyObject *)
{
    const  ::QColor*sipVal;

    sipVal = new  ::QColor( ::QColorConstants::Svg::snow);

    return sipConvertFromNewType(const_cast< ::QColor *>(sipVal), sipType_QColor, SIP_NULLPTR);
}


extern "C" {static PyObject *varget_QColorConstants_Svg_springgreen(void *, PyObject *, PyObject *);}
static PyObject *varget_QColorConstants_Svg_springgreen(void *, PyObject *, PyObject *)
{
    const  ::QColor*sipVal;

    sipVal = new  ::QColor( ::QColorConstants::Svg::springgreen);

    return sipConvertFromNewType(const_cast< ::QColor *>(sipVal), sipType_QColor, SIP_NULLPTR);
}


extern "C" {static PyObject *varget_QColorConstants_Svg_steelblue(void *, PyObject *, PyObject *);}
static PyObject *varget_QColorConstants_Svg_steelblue(void *, PyObject *, PyObject *)
{
    const  ::QColor*sipVal;

    sipVal = new  ::QColor( ::QColorConstants::Svg::steelblue);

    return sipConvertFromNewType(const_cast< ::QColor *>(sipVal), sipType_QColor, SIP_NULLPTR);
}


extern "C" {static PyObject *varget_QColorConstants_Svg_tan(void *, PyObject *, PyObject *);}
static PyObject *varget_QColorConstants_Svg_tan(void *, PyObject *, PyObject *)
{
    const  ::QColor*sipVal;

    sipVal = new  ::QColor( ::QColorConstants::Svg::tan);

    return sipConvertFromNewType(const_cast< ::QColor *>(sipVal), sipType_QColor, SIP_NULLPTR);
}


extern "C" {static PyObject *varget_QColorConstants_Svg_teal(void *, PyObject *, PyObject *);}
static PyObject *varget_QColorConstants_Svg_teal(void *, PyObject *, PyObject *)
{
    const  ::QColor*sipVal;

    sipVal = new  ::QColor( ::QColorConstants::Svg::teal);

    return sipConvertFromNewType(const_cast< ::QColor *>(sipVal), sipType_QColor, SIP_NULLPTR);
}


extern "C" {static PyObject *varget_QColorConstants_Svg_thistle(void *, PyObject *, PyObject *);}
static PyObject *varget_QColorConstants_Svg_thistle(void *, PyObject *, PyObject *)
{
    const  ::QColor*sipVal;

    sipVal = new  ::QColor( ::QColorConstants::Svg::thistle);

    return sipConvertFromNewType(const_cast< ::QColor *>(sipVal), sipType_QColor, SIP_NULLPTR);
}


extern "C" {static PyObject *varget_QColorConstants_Svg_tomato(void *, PyObject *, PyObject *);}
static PyObject *varget_QColorConstants_Svg_tomato(void *, PyObject *, PyObject *)
{
    const  ::QColor*sipVal;

    sipVal = new  ::QColor( ::QColorConstants::Svg::tomato);

    return sipConvertFromNewType(const_cast< ::QColor *>(sipVal), sipType_QColor, SIP_NULLPTR);
}


extern "C" {static PyObject *varget_QColorConstants_Svg_turquoise(void *, PyObject *, PyObject *);}
static PyObject *varget_QColorConstants_Svg_turquoise(void *, PyObject *, PyObject *)
{
    const  ::QColor*sipVal;

    sipVal = new  ::QColor( ::QColorConstants::Svg::turquoise);

    return sipConvertFromNewType(const_cast< ::QColor *>(sipVal), sipType_QColor, SIP_NULLPTR);
}


extern "C" {static PyObject *varget_QColorConstants_Svg_violet(void *, PyObject *, PyObject *);}
static PyObject *varget_QColorConstants_Svg_violet(void *, PyObject *, PyObject *)
{
    const  ::QColor*sipVal;

    sipVal = new  ::QColor( ::QColorConstants::Svg::violet);

    return sipConvertFromNewType(const_cast< ::QColor *>(sipVal), sipType_QColor, SIP_NULLPTR);
}


extern "C" {static PyObject *varget_QColorConstants_Svg_wheat(void *, PyObject *, PyObject *);}
static PyObject *varget_QColorConstants_Svg_wheat(void *, PyObject *, PyObject *)
{
    const  ::QColor*sipVal;

    sipVal = new  ::QColor( ::QColorConstants::Svg::wheat);

    return sipConvertFromNewType(const_cast< ::QColor *>(sipVal), sipType_QColor, SIP_NULLPTR);
}


extern "C" {static PyObject *varget_QColorConstants_Svg_white(void *, PyObject *, PyObject *);}
static PyObject *varget_QColorConstants_Svg_white(void *, PyObject *, PyObject *)
{
    const  ::QColor*sipVal;

    sipVal = new  ::QColor( ::QColorConstants::Svg::white);

    return sipConvertFromNewType(const_cast< ::QColor *>(sipVal), sipType_QColor, SIP_NULLPTR);
}


extern "C" {static PyObject *varget_QColorConstants_Svg_whitesmoke(void *, PyObject *, PyObject *);}
static PyObject *varget_QColorConstants_Svg_whitesmoke(void *, PyObject *, PyObject *)
{
    const  ::QColor*sipVal;

    sipVal = new  ::QColor( ::QColorConstants::Svg::whitesmoke);

    return sipConvertFromNewType(const_cast< ::QColor *>(sipVal), sipType_QColor, SIP_NULLPTR);
}


extern "C" {static PyObject *varget_QColorConstants_Svg_yellow(void *, PyObject *, PyObject *);}
static PyObject *varget_QColorConstants_Svg_yellow(void *, PyObject *, PyObject *)
{
    const  ::QColor*sipVal;

    sipVal = new  ::QColor( ::QColorConstants::Svg::yellow);

    return sipConvertFromNewType(const_cast< ::QColor *>(sipVal), sipType_QColor, SIP_NULLPTR);
}


extern "C" {static PyObject *varget_QColorConstants_Svg_yellowgreen(void *, PyObject *, PyObject *);}
static PyObject *varget_QColorConstants_Svg_yellowgreen(void *, PyObject *, PyObject *)
{
    const  ::QColor*sipVal;

    sipVal = new  ::QColor( ::QColorConstants::Svg::yellowgreen);

    return sipConvertFromNewType(const_cast< ::QColor *>(sipVal), sipType_QColor, SIP_NULLPTR);
}

sipVariableDef variables_QColorConstants_Svg[] = {
    {ClassVariable, sipName_aliceblue, (PyMethodDef *)varget_QColorConstants_Svg_aliceblue, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    {ClassVariable, sipName_antiquewhite, (PyMethodDef *)varget_QColorConstants_Svg_antiquewhite, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    {ClassVariable, sipName_aqua, (PyMethodDef *)varget_QColorConstants_Svg_aqua, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    {ClassVariable, sipName_aquamarine, (PyMethodDef *)varget_QColorConstants_Svg_aquamarine, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    {ClassVariable, sipName_azure, (PyMethodDef *)varget_QColorConstants_Svg_azure, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    {ClassVariable, sipName_beige, (PyMethodDef *)varget_QColorConstants_Svg_beige, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    {ClassVariable, sipName_bisque, (PyMethodDef *)varget_QColorConstants_Svg_bisque, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    {ClassVariable, sipName_black, (PyMethodDef *)varget_QColorConstants_Svg_black, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    {ClassVariable, sipName_blanchedalmond, (PyMethodDef *)varget_QColorConstants_Svg_blanchedalmond, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    {ClassVariable, sipName_blue, (PyMethodDef *)varget_QColorConstants_Svg_blue, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    {ClassVariable, sipName_blueviolet, (PyMethodDef *)varget_QColorConstants_Svg_blueviolet, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    {ClassVariable, sipName_brown, (PyMethodDef *)varget_QColorConstants_Svg_brown, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    {ClassVariable, sipName_burlywood, (PyMethodDef *)varget_QColorConstants_Svg_burlywood, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    {ClassVariable, sipName_cadetblue, (PyMethodDef *)varget_QColorConstants_Svg_cadetblue, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    {ClassVariable, sipName_chartreuse, (PyMethodDef *)varget_QColorConstants_Svg_chartreuse, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    {ClassVariable, sipName_chocolate, (PyMethodDef *)varget_QColorConstants_Svg_chocolate, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    {ClassVariable, sipName_coral, (PyMethodDef *)varget_QColorConstants_Svg_coral, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    {ClassVariable, sipName_cornflowerblue, (PyMethodDef *)varget_QColorConstants_Svg_cornflowerblue, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    {ClassVariable, sipName_cornsilk, (PyMethodDef *)varget_QColorConstants_Svg_cornsilk, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    {ClassVariable, sipName_crimson, (PyMethodDef *)varget_QColorConstants_Svg_crimson, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    {ClassVariable, sipName_cyan, (PyMethodDef *)varget_QColorConstants_Svg_cyan, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    {ClassVariable, sipName_darkblue, (PyMethodDef *)varget_QColorConstants_Svg_darkblue, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    {ClassVariable, sipName_darkcyan, (PyMethodDef *)varget_QColorConstants_Svg_darkcyan, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    {ClassVariable, sipName_darkgoldenrod, (PyMethodDef *)varget_QColorConstants_Svg_darkgoldenrod, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    {ClassVariable, sipName_darkgray, (PyMethodDef *)varget_QColorConstants_Svg_darkgray, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    {ClassVariable, sipName_darkgreen, (PyMethodDef *)varget_QColorConstants_Svg_darkgreen, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    {ClassVariable, sipName_darkgrey, (PyMethodDef *)varget_QColorConstants_Svg_darkgrey, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    {ClassVariable, sipName_darkkhaki, (PyMethodDef *)varget_QColorConstants_Svg_darkkhaki, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    {ClassVariable, sipName_darkmagenta, (PyMethodDef *)varget_QColorConstants_Svg_darkmagenta, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    {ClassVariable, sipName_darkolivegreen, (PyMethodDef *)varget_QColorConstants_Svg_darkolivegreen, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    {ClassVariable, sipName_darkorange, (PyMethodDef *)varget_QColorConstants_Svg_darkorange, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    {ClassVariable, sipName_darkorchid, (PyMethodDef *)varget_QColorConstants_Svg_darkorchid, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    {ClassVariable, sipName_darkred, (PyMethodDef *)varget_QColorConstants_Svg_darkred, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    {ClassVariable, sipName_darksalmon, (PyMethodDef *)varget_QColorConstants_Svg_darksalmon, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    {ClassVariable, sipName_darkseagreen, (PyMethodDef *)varget_QColorConstants_Svg_darkseagreen, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    {ClassVariable, sipName_darkslateblue, (PyMethodDef *)varget_QColorConstants_Svg_darkslateblue, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    {ClassVariable, sipName_darkslategray, (PyMethodDef *)varget_QColorConstants_Svg_darkslategray, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    {ClassVariable, sipName_darkslategrey, (PyMethodDef *)varget_QColorConstants_Svg_darkslategrey, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    {ClassVariable, sipName_darkturquoise, (PyMethodDef *)varget_QColorConstants_Svg_darkturquoise, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    {ClassVariable, sipName_darkviolet, (PyMethodDef *)varget_QColorConstants_Svg_darkviolet, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    {ClassVariable, sipName_deeppink, (PyMethodDef *)varget_QColorConstants_Svg_deeppink, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    {ClassVariable, sipName_deepskyblue, (PyMethodDef *)varget_QColorConstants_Svg_deepskyblue, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    {ClassVariable, sipName_dimgray, (PyMethodDef *)varget_QColorConstants_Svg_dimgray, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    {ClassVariable, sipName_dimgrey, (PyMethodDef *)varget_QColorConstants_Svg_dimgrey, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    {ClassVariable, sipName_dodgerblue, (PyMethodDef *)varget_QColorConstants_Svg_dodgerblue, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    {ClassVariable, sipName_firebrick, (PyMethodDef *)varget_QColorConstants_Svg_firebrick, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    {ClassVariable, sipName_floralwhite, (PyMethodDef *)varget_QColorConstants_Svg_floralwhite, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    {ClassVariable, sipName_forestgreen, (PyMethodDef *)varget_QColorConstants_Svg_forestgreen, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    {ClassVariable, sipName_fuchsia, (PyMethodDef *)varget_QColorConstants_Svg_fuchsia, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    {ClassVariable, sipName_gainsboro, (PyMethodDef *)varget_QColorConstants_Svg_gainsboro, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    {ClassVariable, sipName_ghostwhite, (PyMethodDef *)varget_QColorConstants_Svg_ghostwhite, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    {ClassVariable, sipName_gold, (PyMethodDef *)varget_QColorConstants_Svg_gold, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    {ClassVariable, sipName_goldenrod, (PyMethodDef *)varget_QColorConstants_Svg_goldenrod, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    {ClassVariable, sipName_gray, (PyMethodDef *)varget_QColorConstants_Svg_gray, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    {ClassVariable, sipName_green, (PyMethodDef *)varget_QColorConstants_Svg_green, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    {ClassVariable, sipName_greenyellow, (PyMethodDef *)varget_QColorConstants_Svg_greenyellow, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    {ClassVariable, sipName_grey, (PyMethodDef *)varget_QColorConstants_Svg_grey, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    {ClassVariable, sipName_honeydew, (PyMethodDef *)varget_QColorConstants_Svg_honeydew, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    {ClassVariable, sipName_hotpink, (PyMethodDef *)varget_QColorConstants_Svg_hotpink, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    {ClassVariable, sipName_indianred, (PyMethodDef *)varget_QColorConstants_Svg_indianred, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    {ClassVariable, sipName_indigo, (PyMethodDef *)varget_QColorConstants_Svg_indigo, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    {ClassVariable, sipName_ivory, (PyMethodDef *)varget_QColorConstants_Svg_ivory, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    {ClassVariable, sipName_khaki, (PyMethodDef *)varget_QColorConstants_Svg_khaki, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    {ClassVariable, sipName_lavender, (PyMethodDef *)varget_QColorConstants_Svg_lavender, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    {ClassVariable, sipName_lavenderblush, (PyMethodDef *)varget_QColorConstants_Svg_lavenderblush, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    {ClassVariable, sipName_lawngreen, (PyMethodDef *)varget_QColorConstants_Svg_lawngreen, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    {ClassVariable, sipName_lemonchiffon, (PyMethodDef *)varget_QColorConstants_Svg_lemonchiffon, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    {ClassVariable, sipName_lightblue, (PyMethodDef *)varget_QColorConstants_Svg_lightblue, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    {ClassVariable, sipName_lightcoral, (PyMethodDef *)varget_QColorConstants_Svg_lightcoral, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    {ClassVariable, sipName_lightcyan, (PyMethodDef *)varget_QColorConstants_Svg_lightcyan, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    {ClassVariable, sipName_lightgoldenrodyellow, (PyMethodDef *)varget_QColorConstants_Svg_lightgoldenrodyellow, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    {ClassVariable, sipName_lightgray, (PyMethodDef *)varget_QColorConstants_Svg_lightgray, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    {ClassVariable, sipName_lightgreen, (PyMethodDef *)varget_QColorConstants_Svg_lightgreen, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    {ClassVariable, sipName_lightgrey, (PyMethodDef *)varget_QColorConstants_Svg_lightgrey, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    {ClassVariable, sipName_lightpink, (PyMethodDef *)varget_QColorConstants_Svg_lightpink, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    {ClassVariable, sipName_lightsalmon, (PyMethodDef *)varget_QColorConstants_Svg_lightsalmon, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    {ClassVariable, sipName_lightseagreen, (PyMethodDef *)varget_QColorConstants_Svg_lightseagreen, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    {ClassVariable, sipName_lightskyblue, (PyMethodDef *)varget_QColorConstants_Svg_lightskyblue, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    {ClassVariable, sipName_lightslategray, (PyMethodDef *)varget_QColorConstants_Svg_lightslategray, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    {ClassVariable, sipName_lightslategrey, (PyMethodDef *)varget_QColorConstants_Svg_lightslategrey, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    {ClassVariable, sipName_lightsteelblue, (PyMethodDef *)varget_QColorConstants_Svg_lightsteelblue, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    {ClassVariable, sipName_lightyellow, (PyMethodDef *)varget_QColorConstants_Svg_lightyellow, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    {ClassVariable, sipName_lime, (PyMethodDef *)varget_QColorConstants_Svg_lime, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    {ClassVariable, sipName_limegreen, (PyMethodDef *)varget_QColorConstants_Svg_limegreen, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    {ClassVariable, sipName_linen, (PyMethodDef *)varget_QColorConstants_Svg_linen, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    {ClassVariable, sipName_magenta, (PyMethodDef *)varget_QColorConstants_Svg_magenta, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    {ClassVariable, sipName_maroon, (PyMethodDef *)varget_QColorConstants_Svg_maroon, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    {ClassVariable, sipName_mediumaquamarine, (PyMethodDef *)varget_QColorConstants_Svg_mediumaquamarine, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    {ClassVariable, sipName_mediumblue, (PyMethodDef *)varget_QColorConstants_Svg_mediumblue, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    {ClassVariable, sipName_mediumorchid, (PyMethodDef *)varget_QColorConstants_Svg_mediumorchid, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    {ClassVariable, sipName_mediumpurple, (PyMethodDef *)varget_QColorConstants_Svg_mediumpurple, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    {ClassVariable, sipName_mediumseagreen, (PyMethodDef *)varget_QColorConstants_Svg_mediumseagreen, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    {ClassVariable, sipName_mediumslateblue, (PyMethodDef *)varget_QColorConstants_Svg_mediumslateblue, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    {ClassVariable, sipName_mediumspringgreen, (PyMethodDef *)varget_QColorConstants_Svg_mediumspringgreen, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    {ClassVariable, sipName_mediumturquoise, (PyMethodDef *)varget_QColorConstants_Svg_mediumturquoise, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    {ClassVariable, sipName_mediumvioletred, (PyMethodDef *)varget_QColorConstants_Svg_mediumvioletred, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    {ClassVariable, sipName_midnightblue, (PyMethodDef *)varget_QColorConstants_Svg_midnightblue, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    {ClassVariable, sipName_mintcream, (PyMethodDef *)varget_QColorConstants_Svg_mintcream, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    {ClassVariable, sipName_mistyrose, (PyMethodDef *)varget_QColorConstants_Svg_mistyrose, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    {ClassVariable, sipName_moccasin, (PyMethodDef *)varget_QColorConstants_Svg_moccasin, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    {ClassVariable, sipName_navajowhite, (PyMethodDef *)varget_QColorConstants_Svg_navajowhite, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    {ClassVariable, sipName_navy, (PyMethodDef *)varget_QColorConstants_Svg_navy, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    {ClassVariable, sipName_oldlace, (PyMethodDef *)varget_QColorConstants_Svg_oldlace, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    {ClassVariable, sipName_olive, (PyMethodDef *)varget_QColorConstants_Svg_olive, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    {ClassVariable, sipName_olivedrab, (PyMethodDef *)varget_QColorConstants_Svg_olivedrab, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    {ClassVariable, sipName_orange, (PyMethodDef *)varget_QColorConstants_Svg_orange, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    {ClassVariable, sipName_orangered, (PyMethodDef *)varget_QColorConstants_Svg_orangered, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    {ClassVariable, sipName_orchid, (PyMethodDef *)varget_QColorConstants_Svg_orchid, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    {ClassVariable, sipName_palegoldenrod, (PyMethodDef *)varget_QColorConstants_Svg_palegoldenrod, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    {ClassVariable, sipName_palegreen, (PyMethodDef *)varget_QColorConstants_Svg_palegreen, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    {ClassVariable, sipName_paleturquoise, (PyMethodDef *)varget_QColorConstants_Svg_paleturquoise, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    {ClassVariable, sipName_palevioletred, (PyMethodDef *)varget_QColorConstants_Svg_palevioletred, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    {ClassVariable, sipName_papayawhip, (PyMethodDef *)varget_QColorConstants_Svg_papayawhip, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    {ClassVariable, sipName_peachpuff, (PyMethodDef *)varget_QColorConstants_Svg_peachpuff, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    {ClassVariable, sipName_peru, (PyMethodDef *)varget_QColorConstants_Svg_peru, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    {ClassVariable, sipName_pink, (PyMethodDef *)varget_QColorConstants_Svg_pink, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    {ClassVariable, sipName_plum, (PyMethodDef *)varget_QColorConstants_Svg_plum, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    {ClassVariable, sipName_powderblue, (PyMethodDef *)varget_QColorConstants_Svg_powderblue, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    {ClassVariable, sipName_purple, (PyMethodDef *)varget_QColorConstants_Svg_purple, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    {ClassVariable, sipName_red, (PyMethodDef *)varget_QColorConstants_Svg_red, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    {ClassVariable, sipName_rosybrown, (PyMethodDef *)varget_QColorConstants_Svg_rosybrown, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    {ClassVariable, sipName_royalblue, (PyMethodDef *)varget_QColorConstants_Svg_royalblue, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    {ClassVariable, sipName_saddlebrown, (PyMethodDef *)varget_QColorConstants_Svg_saddlebrown, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    {ClassVariable, sipName_salmon, (PyMethodDef *)varget_QColorConstants_Svg_salmon, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    {ClassVariable, sipName_sandybrown, (PyMethodDef *)varget_QColorConstants_Svg_sandybrown, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    {ClassVariable, sipName_seagreen, (PyMethodDef *)varget_QColorConstants_Svg_seagreen, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    {ClassVariable, sipName_seashell, (PyMethodDef *)varget_QColorConstants_Svg_seashell, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    {ClassVariable, sipName_sienna, (PyMethodDef *)varget_QColorConstants_Svg_sienna, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    {ClassVariable, sipName_silver, (PyMethodDef *)varget_QColorConstants_Svg_silver, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    {ClassVariable, sipName_skyblue, (PyMethodDef *)varget_QColorConstants_Svg_skyblue, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    {ClassVariable, sipName_slateblue, (PyMethodDef *)varget_QColorConstants_Svg_slateblue, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    {ClassVariable, sipName_slategray, (PyMethodDef *)varget_QColorConstants_Svg_slategray, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    {ClassVariable, sipName_slategrey, (PyMethodDef *)varget_QColorConstants_Svg_slategrey, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    {ClassVariable, sipName_snow, (PyMethodDef *)varget_QColorConstants_Svg_snow, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    {ClassVariable, sipName_springgreen, (PyMethodDef *)varget_QColorConstants_Svg_springgreen, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    {ClassVariable, sipName_steelblue, (PyMethodDef *)varget_QColorConstants_Svg_steelblue, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    {ClassVariable, sipName_tan, (PyMethodDef *)varget_QColorConstants_Svg_tan, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    {ClassVariable, sipName_teal, (PyMethodDef *)varget_QColorConstants_Svg_teal, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    {ClassVariable, sipName_thistle, (PyMethodDef *)varget_QColorConstants_Svg_thistle, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    {ClassVariable, sipName_tomato, (PyMethodDef *)varget_QColorConstants_Svg_tomato, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    {ClassVariable, sipName_turquoise, (PyMethodDef *)varget_QColorConstants_Svg_turquoise, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    {ClassVariable, sipName_violet, (PyMethodDef *)varget_QColorConstants_Svg_violet, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    {ClassVariable, sipName_wheat, (PyMethodDef *)varget_QColorConstants_Svg_wheat, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    {ClassVariable, sipName_white, (PyMethodDef *)varget_QColorConstants_Svg_white, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    {ClassVariable, sipName_whitesmoke, (PyMethodDef *)varget_QColorConstants_Svg_whitesmoke, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    {ClassVariable, sipName_yellow, (PyMethodDef *)varget_QColorConstants_Svg_yellow, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    {ClassVariable, sipName_yellowgreen, (PyMethodDef *)varget_QColorConstants_Svg_yellowgreen, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
};


static pyqt5ClassPluginDef plugin_QColorConstants_Svg = {
    SIP_NULLPTR,
    0,
    SIP_NULLPTR,
    SIP_NULLPTR
};


sipClassTypeDef sipTypeDef_QtGui_QColorConstants_Svg = {
    {
        -1,
        SIP_NULLPTR,
        SIP_NULLPTR,
        SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_NAMESPACE,
        sipNameNr_QColorConstants__Svg,
        {SIP_NULLPTR},
        &plugin_QColorConstants_Svg
    },
    {
        sipNameNr_Svg,
        {15, 255, 0},
        0, SIP_NULLPTR,
        0, SIP_NULLPTR,
        147, variables_QColorConstants_Svg,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    SIP_NULLPTR,
    -1,
    -1,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
#if PY_MAJOR_VERSION >= 3
    SIP_NULLPTR,
    SIP_NULLPTR,
#else
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
#endif
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR
};
